#include "bios.h"

const char* ffDetectBios(FF_MAYBE_UNUSED FFBiosResult* bios)
{
    return "Not supported on this platform";
}
